@@ -15,11 +15,9 @@ use WebDAO::Base;
 use CGI;
 use MIME::Base64;
 use Digest::MD5 qw(md5_hex);
-
 use base qw( WebDAO::Session );
-
 use strict 'vars';
-__PACKAGE__->attributes qw( Cookie_name Db_file );
+__PACKAGE__->mk_attr ( Cookie_name=>undef, Db_file=>undef );
 
 sub Init {
 
@@ -42,8 +40,8 @@ sub Init {
     my $coo = $cv->get_cookie->{ $id };
     unless ($coo) {
         $coo = md5_hex(time ^ $$, rand(999)) ;
-        U_id $self ( $coo );
     }
+     U_id $self ( $coo );
     $self->Cookie_name()->{value} = $coo;
     $self->Cookie_name()->{expires} = time()+ 60*60*24*30*3; # 3 month
     $cv->set_header('Set-Cookie', $self->Cookie_name());
